@@ -9,7 +9,7 @@
 #                        |  |_|  /  |  |  /  |  |  / \_
 #                         \/  |_/   |_/|_/\_/|_/|_/ \/
 
-__version__ = '0.1.4'
+__version__ = '0.1.5'
 
 import re
 
@@ -267,6 +267,7 @@ class ReportVisitor:
     string = ''
 
     def permute_schedule(self, node):  return [[0]]
+    def step_schedule(self, node):  return [ [ x for x in range(len(node.steps)) ] ]
 
     def visit(self, node):
         recon, we_owe =  node.to_html()
@@ -284,7 +285,8 @@ class TestVisitor:
     def __init__(self, suite):  self.suite = suite
 
     def permute_schedule(self, node):  return node.permute_schedule()
-        
+    def step_schedule(self, node):  return node.step_schedule()
+
     def visit(self, node):
         # print node.reconstruction()  # CONSIDER  if verbose
         self.suite.step = node
@@ -300,7 +302,9 @@ class Feature(Morelia):
         self.enforce(0 < len(self.steps), 'Feature without Scenario(s)')
 
     def to_html(self):
-        return ['\n<div><table><tr><td align="right" valign="top" width="100"><em>' + self.concept + '</em>:</td><td colspan="101">' + 
+        return ['\n<div><table><tr style="background-color: #aaffbb;" width="100%">' +
+                                  '<td align="right" valign="top" width="100">' + 
+                                  '<em>' + self.concept + '</em>:</td><td colspan="101">' + 
                                     _clean_html(self.predicate) + '</td></tr></table></div>', '']
 
 
@@ -308,13 +312,16 @@ class Scenario(Morelia):
     def my_parent_type(self):  return Feature
 
     def evaluate_steps(self, visitor):
-        schedule = visitor.permute_schedule(self)
+        step_schedule = visitor.step_schedule(self)  #  TODO  test this permuter directly (and rename it already)
 
-        for indices in schedule:
-            self.row_indices = indices
-            self.evaluate_test_case(visitor)  #  note this works on reports too!
+        for step_indices in step_schedule:   #  TODO  think of a way to TDD this C-:
+            schedule = visitor.permute_schedule(self)
+
+            for indices in schedule:
+                self.row_indices = indices
+                self.evaluate_test_case(visitor, step_indices)  #  note this works on reports too!
     
-    def evaluate_test_case(self, visitor):  #  note this permutes reports too!
+    def evaluate_test_case(self, visitor, step_indices = None):  #  note this permutes reports too!
         self.enforce(0 < len(self.steps), 'Scenario without step(s) - Step, Given, When, Then, And, or #')
 
         name = self.steps[0].find_step_name(visitor.suite)
@@ -324,15 +331,46 @@ class Scenario(Morelia):
 
         try:
             u_owe = visitor.visit(self)
-            for step in self.steps:  step.evaluate_steps(visitor)
+            
+            for idx, step in enumerate(self.steps):  
+                if step_indices == None or idx in step_indices:  #  TODO  take out the default arg
+                    step.evaluate_steps(visitor)
+                    
             visitor.owed(u_owe)
         finally:
             visitor.suite.tearDown()
 
-    def permute_schedule(self):
+    def permute_schedule(self):  #  TODO  rename to permute_row_schedule
         dims = self.count_Row_dimensions()
         return _permute_indices(dims)
 
+    def step_schedule(self):  #  TODO  rename to permute_step_schedule !
+        sched = []
+        pre_slug = []
+        
+        #  TODO   deal with steps w/o whens
+
+        for idx, s in enumerate(self.steps):
+            if s.__class__ == When:
+                break
+            else:
+                pre_slug.append(idx)
+
+        for idx, s in enumerate(self.steps):
+            if s.__class__ == When:
+                slug = pre_slug[:]
+                slug.append(idx)
+
+                for idx in range(idx + 1, len(self.steps)):
+                    s = self.steps[idx]
+                    if s.__class__ == When:  break
+                    slug.append(idx)
+                        
+                sched.append(slug)
+
+        if sched == []:  return [pre_slug]
+        return sched
+
     def _embellish(self):
         self.row_indices = []
         
@@ -419,6 +457,8 @@ class Given(Step):   #  CONSIDER  distinguish these by fault signatures!
     def prefix(self):  return '  '
 class When(Step):  #  TODO  cycle these against the Scenario
     def prefix(self):  return '   '
+    def to_html(self):
+        return '\n<tr style="background-color: #cdffb8;"><td align="right" valign="top"><em>' + self.concept + '</em></td><td colspan="101">' + _clean_html(self.predicate) + '</td></tr>', ''
 class Then(Step):
     def prefix(self):  return '   '
 class And(Step):  
